==> jc-1.4.0.tar.gz: java/awt/font/ShapeGraphicAttribute.h <==
// public final class java.awt.font.ShapeGraphicAttribute

// class file dependencies
// @dep_class a87844304b3211dc java_awt_font_GraphicAttribute
// @dep_class 2e003dc2e9ad87cf java_awt_font_ShapeGraphicAttribute
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_font_GraphicAttribute

#include "java/awt/font/GraphicAttribute.h"

#ifndef _JC_java_awt_font_ShapeGraphicAttribute_H_
#define _JC_java_awt_font_ShapeGraphicAttribute_H_

// Forward structure declarations
struct _jc_java_awt_Graphics2D$object;
struct _jc_java_awt_Shape$object;
struct _jc_java_awt_font_ShapeGraphicAttribute$object;
struct _jc_java_awt_geom_Rectangle2D$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_font_ShapeGraphicAttribute$sub_refs	_jc_java_awt_font_ShapeGraphicAttribute$sub_refs;
typedef struct _jc_java_awt_font_ShapeGraphicAttribute$sub_nonrefs	_jc_java_awt_font_ShapeGraphicAttribute$sub_nonrefs;
typedef struct _jc_java_awt_font_ShapeGraphicAttribute$refs	_jc_java_awt_font_ShapeGraphicAttribute$refs;
typedef struct _jc_java_awt_font_ShapeGraphicAttribute$nonrefs	_jc_java_awt_font_ShapeGraphicAttribute$nonrefs;
typedef struct _jc_java_awt_font_ShapeGraphicAttribute$object	_jc_java_awt_font_ShapeGraphicAttribute$object;

typedef struct _jc_java_awt_font_ShapeGraphicAttribute$fields_struct	_jc_java_awt_font_ShapeGraphicAttribute$fields_struct;
typedef const struct _jc_java_awt_font_ShapeGraphicAttribute$vmethods	_jc_java_awt_font_ShapeGraphicAttribute$vmethods;
typedef const struct _jc_java_awt_font_ShapeGraphicAttribute$vtable	_jc_java_awt_font_ShapeGraphicAttribute$vtable;
typedef const struct _jc_java_awt_font_ShapeGraphicAttribute$vtype	_jc_java_awt_font_ShapeGraphicAttribute$vtype;

// Class fields structure
struct _jc_java_awt_font_ShapeGraphicAttribute$fields_struct {
	jboolean	FILL;
	jboolean	STROKE;
};
extern _jc_java_awt_font_ShapeGraphicAttribute$fields_struct _jc_java_awt_font_ShapeGraphicAttribute$class_fields;

// Constructors
extern void _jc_java_awt_font_ShapeGraphicAttribute$method$_init$f96219773edb9cbe(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *, struct _jc_object *, jint, jboolean);

// Virtual methods
extern void _jc_java_awt_font_ShapeGraphicAttribute$method$draw$f3841a017f030b9d(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *, struct _jc_java_awt_Graphics2D$object *, jfloat, jfloat);
extern jboolean _jc_java_awt_font_ShapeGraphicAttribute$method$equals$ea7c956e9bf3666b(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *);
extern jboolean _jc_java_awt_font_ShapeGraphicAttribute$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *, struct _jc_java_lang_Object$object *);
extern jfloat _jc_java_awt_font_ShapeGraphicAttribute$method$getAdvance$816f64db01e9ba98(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *);
extern jfloat _jc_java_awt_font_ShapeGraphicAttribute$method$getAscent$1128a319fbdd8fc1(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *);
extern struct _jc_java_awt_geom_Rectangle2D$object *_jc_java_awt_font_ShapeGraphicAttribute$method$getBounds$5108fa3dfa118dd0(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *);
extern jfloat _jc_java_awt_font_ShapeGraphicAttribute$method$getDescent$38195f27867c5f73(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *);
extern jint _jc_java_awt_font_ShapeGraphicAttribute$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_font_ShapeGraphicAttribute$method_info$draw$f3841a017f030b9d;
extern _jc_method _jc_java_awt_font_ShapeGraphicAttribute$method_info$equals$ea7c956e9bf3666b;
extern _jc_method _jc_java_awt_font_ShapeGraphicAttribute$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_awt_font_ShapeGraphicAttribute$method_info$getAdvance$816f64db01e9ba98;
extern _jc_method _jc_java_awt_font_ShapeGraphicAttribute$method_info$getAscent$1128a319fbdd8fc1;
extern _jc_method _jc_java_awt_font_ShapeGraphicAttribute$method_info$getBounds$5108fa3dfa118dd0;
extern _jc_method _jc_java_awt_font_ShapeGraphicAttribute$method_info$getDescent$38195f27867c5f73;
extern _jc_method _jc_java_awt_font_ShapeGraphicAttribute$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_awt_font_ShapeGraphicAttribute$vmethods {
	void	(*draw$f3841a017f030b9d)(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *, struct _jc_java_awt_Graphics2D$object *, jfloat, jfloat);
	jboolean	(*equals$ea7c956e9bf3666b)(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *, struct _jc_java_lang_Object$object *);
	jfloat	(*getAdvance$816f64db01e9ba98)(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *);
	jfloat	(*getAscent$1128a319fbdd8fc1)(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *);
	struct _jc_java_awt_geom_Rectangle2D$object	*(*getBounds$5108fa3dfa118dd0)(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *);
	jfloat	(*getDescent$38195f27867c5f73)(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *);
};

// Vtable
struct _jc_java_awt_font_ShapeGraphicAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_font_GraphicAttribute$vmethods	java_awt_font_GraphicAttribute;
	_jc_java_awt_font_ShapeGraphicAttribute$vmethods	java_awt_font_ShapeGraphicAttribute;
};

// Vtype
struct _jc_java_awt_font_ShapeGraphicAttribute$vtype {
	_jc_type			type;
	_jc_java_awt_font_ShapeGraphicAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_font_ShapeGraphicAttribute$sub_refs {
	struct _jc_object	*shape;
};

// Reference instance fields (object)
struct _jc_java_awt_font_ShapeGraphicAttribute$refs {
    _jc_java_awt_font_ShapeGraphicAttribute$sub_refs	java_awt_font_ShapeGraphicAttribute;
    _jc_java_awt_font_GraphicAttribute$sub_refs	java_awt_font_GraphicAttribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_font_ShapeGraphicAttribute$sub_nonrefs {
	jboolean	stroke;
};

// Non-reference instance fields (object)
struct _jc_java_awt_font_ShapeGraphicAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_font_GraphicAttribute$sub_nonrefs	java_awt_font_GraphicAttribute;
    _jc_java_awt_font_ShapeGraphicAttribute$sub_nonrefs	java_awt_font_ShapeGraphicAttribute;
};

// Object instance structure
struct _jc_java_awt_font_ShapeGraphicAttribute$object {
	_jc_java_awt_font_ShapeGraphicAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_font_ShapeGraphicAttribute$vtype	*vtype;
	_jc_java_awt_font_ShapeGraphicAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_font_ShapeGraphicAttribute$vtype _jc_java_awt_font_ShapeGraphicAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_font_ShapeGraphicAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_font_ShapeGraphicAttribute$class_object;

#endif	/* _JC_java_awt_font_ShapeGraphicAttribute_H_ */

==> jc-1.4.6.tar.gz: java/awt/font/ShapeGraphicAttribute.h <==
// public final class java.awt.font.ShapeGraphicAttribute

// class file dependencies
// @dep_class a87844304b3211dc java_awt_font_GraphicAttribute
// @dep_class 2e003dc2e9ad87cf java_awt_font_ShapeGraphicAttribute
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_font_GraphicAttribute

#include "java/awt/font/GraphicAttribute.h"

#ifndef _JC_java_awt_font_ShapeGraphicAttribute_H_
#define _JC_java_awt_font_ShapeGraphicAttribute_H_

// Forward structure declarations
struct _jc_java_awt_Graphics2D$object;
struct _jc_java_awt_Shape$object;
struct _jc_java_awt_font_ShapeGraphicAttribute$object;
struct _jc_java_awt_geom_Rectangle2D$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_awt_font_ShapeGraphicAttribute$sub_refs	_jc_java_awt_font_ShapeGraphicAttribute$sub_refs;
typedef struct _jc_java_awt_font_ShapeGraphicAttribute$sub_nonrefs	_jc_java_awt_font_ShapeGraphicAttribute$sub_nonrefs;
typedef struct _jc_java_awt_font_ShapeGraphicAttribute$refs	_jc_java_awt_font_ShapeGraphicAttribute$refs;
typedef struct _jc_java_awt_font_ShapeGraphicAttribute$nonrefs	_jc_java_awt_font_ShapeGraphicAttribute$nonrefs;
typedef struct _jc_java_awt_font_ShapeGraphicAttribute$object	_jc_java_awt_font_ShapeGraphicAttribute$object;

typedef struct _jc_java_awt_font_ShapeGraphicAttribute$fields_struct	_jc_java_awt_font_ShapeGraphicAttribute$fields_struct;
typedef const struct _jc_java_awt_font_ShapeGraphicAttribute$vmethods	_jc_java_awt_font_ShapeGraphicAttribute$vmethods;
typedef const struct _jc_java_awt_font_ShapeGraphicAttribute$vtable	_jc_java_awt_font_ShapeGraphicAttribute$vtable;
typedef const struct _jc_java_awt_font_ShapeGraphicAttribute$vtype	_jc_java_awt_font_ShapeGraphicAttribute$vtype;

// Class fields structure
struct _jc_java_awt_font_ShapeGraphicAttribute$fields_struct {
	jboolean	FILL;
	jboolean	STROKE;
};
extern _jc_java_awt_font_ShapeGraphicAttribute$fields_struct _jc_java_awt_font_ShapeGraphicAttribute$class_fields;

// Constructors
extern void _jc_java_awt_font_ShapeGraphicAttribute$method$_init$f96219773edb9cbe(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *, struct _jc_object *, jint, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_font_ShapeGraphicAttribute$method$draw$f3841a017f030b9d(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *, struct _jc_java_awt_Graphics2D$object *, jfloat, jfloat) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_font_ShapeGraphicAttribute$method$equals$ea7c956e9bf3666b(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_font_ShapeGraphicAttribute$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jfloat _jc_java_awt_font_ShapeGraphicAttribute$method$getAdvance$816f64db01e9ba98(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *) _JC_JCNI_ATTR;
extern jfloat _jc_java_awt_font_ShapeGraphicAttribute$method$getAscent$1128a319fbdd8fc1(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_geom_Rectangle2D$object *_jc_java_awt_font_ShapeGraphicAttribute$method$getBounds$5108fa3dfa118dd0(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *) _JC_JCNI_ATTR;
extern jfloat _jc_java_awt_font_ShapeGraphicAttribute$method$getDescent$38195f27867c5f73(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_font_ShapeGraphicAttribute$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_font_ShapeGraphicAttribute$method_info$draw$f3841a017f030b9d;
extern _jc_method _jc_java_awt_font_ShapeGraphicAttribute$method_info$equals$ea7c956e9bf3666b;
extern _jc_method _jc_java_awt_font_ShapeGraphicAttribute$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_awt_font_ShapeGraphicAttribute$method_info$getAdvance$816f64db01e9ba98;
extern _jc_method _jc_java_awt_font_ShapeGraphicAttribute$method_info$getAscent$1128a319fbdd8fc1;
extern _jc_method _jc_java_awt_font_ShapeGraphicAttribute$method_info$getBounds$5108fa3dfa118dd0;
extern _jc_method _jc_java_awt_font_ShapeGraphicAttribute$method_info$getDescent$38195f27867c5f73;
extern _jc_method _jc_java_awt_font_ShapeGraphicAttribute$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_java_awt_font_ShapeGraphicAttribute$vmethods {
	void	(*draw$f3841a017f030b9d)(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *, struct _jc_java_awt_Graphics2D$object *, jfloat, jfloat) _JC_JCNI_ATTR;
	jboolean	(*equals$ea7c956e9bf3666b)(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jfloat	(*getAdvance$816f64db01e9ba98)(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *) _JC_JCNI_ATTR;
	jfloat	(*getAscent$1128a319fbdd8fc1)(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_geom_Rectangle2D$object	*(*getBounds$5108fa3dfa118dd0)(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *) _JC_JCNI_ATTR;
	jfloat	(*getDescent$38195f27867c5f73)(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_awt_font_ShapeGraphicAttribute$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_font_ShapeGraphicAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_font_GraphicAttribute$vmethods	java_awt_font_GraphicAttribute;
	_jc_java_awt_font_ShapeGraphicAttribute$vmethods	java_awt_font_ShapeGraphicAttribute;
};

// Vtype
struct _jc_java_awt_font_ShapeGraphicAttribute$vtype {
	_jc_type			type;
	_jc_java_awt_font_ShapeGraphicAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_font_ShapeGraphicAttribute$sub_refs {
	struct _jc_object	*shape;
};

// Reference instance fields (object)
struct _jc_java_awt_font_ShapeGraphicAttribute$refs {
    _jc_java_awt_font_ShapeGraphicAttribute$sub_refs	java_awt_font_ShapeGraphicAttribute;
    _jc_java_awt_font_GraphicAttribute$sub_refs	java_awt_font_GraphicAttribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_font_ShapeGraphicAttribute$sub_nonrefs {
	jboolean	stroke;
};

// Non-reference instance fields (object)
struct _jc_java_awt_font_ShapeGraphicAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_font_GraphicAttribute$sub_nonrefs	java_awt_font_GraphicAttribute;
    _jc_java_awt_font_ShapeGraphicAttribute$sub_nonrefs	java_awt_font_ShapeGraphicAttribute;
};

// Object instance structure
struct _jc_java_awt_font_ShapeGraphicAttribute$object {
	_jc_java_awt_font_ShapeGraphicAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_font_ShapeGraphicAttribute$vtype	*vtype;
	_jc_java_awt_font_ShapeGraphicAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_font_ShapeGraphicAttribute$vtype _jc_java_awt_font_ShapeGraphicAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_font_ShapeGraphicAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_font_ShapeGraphicAttribute$class_object;

#endif	/* _JC_java_awt_font_ShapeGraphicAttribute_H_ */
